@@ -69,9 +69,11 @@ class RideModel(QtCore.QObject):
       t, l, s = self.icon
       rul = ''
       if t=='M':
-         url = u'http://fr.wikipedia.org/wiki/Ligne_%s_du_métro_de_Paris'%l
+         url = u"http://fr.wikipedia.org/wiki/Ligne_%s_du_métro_de_Paris"%l
       elif t=='R':
-         url = "http://fr.wikipedia.org/wiki/Ligne_%s_du_RER_d'Ile-de-France"%l
+         url = u"http://fr.wikipedia.org/wiki/Ligne_%s_du_RER_d'Ile-de-France"%l
+      elif t=='T':
+         url = u"http://fr.wikipedia.org/wiki/Ligne_%s_du_tramway_d'Île-de-France"%l
 
       return QtCore.QUrl(url)
 
