@@ -8,8 +8,9 @@ from utils.DebugLog import DebugLog
 from utils.TrainDb import  DbTrain, GareManager
 from utils.Config import TrainTrainConf, ConfFile, RidesConfig
 from extractors.ExtractorTransilien import ExtractorTransilien
-from extractors.ExtractorMetroMobi import ExtractorMetro
-from extractors.ExtractorRERratpMobi import ExtractorRERratp
+from extractors.ExtractorMetro import ExtractorMetro
+from extractors.ExtractorRERratp import ExtractorRERratp
+from extractors.ExtractorTramway import ExtractorTramway
 
 class TrainTrainModel(QAbstractTableModel):
    def __init__(self):
@@ -68,6 +69,9 @@ class TrainTrainModel(QAbstractTableModel):
 
       elif ligne.tec == 'Metro':
          extractor = ExtractorMetro(ligne)
+         
+      elif ligne.tec == 'Tramway':
+         extractor = ExtractorTramway(ligne)
 
       elif ligne.tec == 'RER' and ligne.exploitant=='R': # RATP
          extractor = ExtractorRERratp(ligne)
