@@ -17,7 +17,7 @@ class ConfFile:
          return ''
 
 class RideConf:
-   def __init__(self, ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitant, direction):
+   def __init__(self, ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitant, direction, sens):
       self.ligne = ligne
       self.tec = tec
       self.depart = depart
@@ -26,6 +26,11 @@ class RideConf:
       self.codeArrivee = codeArrivee
       self.exploitant = exploitant
       self.direction = direction
+      self.sens = sens
+
+   def __str__(self):
+      return u"ligne: %s\ntec: %s\ndepart: %s\ncodeDepart: %s\narrivee: %s\ncodeArrivee: %s\nexploitant: %s\ndirection: %s"%\
+      (self.ligne, self.tec, self.depart, self.codeDepart, self.arrivee, self.codeArrivee, self.exploitant, self.direction)
 
 class RidesConfig:
    def __init__(self, filename):
@@ -42,7 +47,6 @@ class RidesConfig:
          DebugLog("  RidesConfig::AddRide(create id%s)"%id)
       self.rides[id] = ride
       ride.id = id
-      DebugLog(str([k for k in sorted(self.rides.keys())]))
 
    def RemoveRide(self, id):
       DebugLog("RidesConfig::RemoveRide(%s)"%id)
@@ -74,9 +78,14 @@ class RidesConfig:
          codeArrivee = t.get(section, 'codeArrivee')
          exploitant = t.get(section, 'exploitant')
          direction = t.get(section, 'direction')
+         sens = 0
+         try:
+            sens = int(t.get(section, 'sens'))
+         except:
+            sens = 0
 
          if codeDepart and codeArrivee and tec and depart and arrivee:
-            l = RideConf(ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitant, direction)
+            l = RideConf(ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitant, direction, sens)
             self.AddRide(l, section)
 
       self.hasChanged = False
@@ -108,6 +117,7 @@ class RidesConfig:
          f.write('codeDepart=%s\n'%ride.codeDepart.strip())
          f.write('codeArrivee=%s\n'%ride.codeArrivee.strip())
          f.write('exploitant=%s\n'%ride.exploitant.strip())
+         f.write('sens=%d\n'%ride.sens)
          if ride.direction:
             f.write('direction=%s\n'%ride.direction.strip())
 
