@@ -286,6 +286,8 @@ class AddRideDlg(QtGui.QDialog):
          tec = 'Metro'
       elif ligne[0]=='R':
          tec = 'RER'
+      elif ligne[0]=='T':
+         tec = 'Tramway'
       else:
          raise RuntimeError('tec inconnu "%s"'%ligne)
 
@@ -296,7 +298,7 @@ class AddRideDlg(QtGui.QDialog):
       if res[3]:
          posDepart = int(res[3])
 
-      req = "SELECT name, code, exploitant, position FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid AND ligne='%s'" % (arrivee, ligne)
+      req = 'SELECT name, code, exploitant, position FROM gares, lignes WHERE gares.name="%s" AND gares.rowid=lignes.gareid AND ligne="%s"' % (arrivee, ligne)
       DebugLog(req)
       c = self.db.execute(req)
       res = c.fetchone()
